@@ -10,9 +10,6 @@ import (
 	"github.com/skupperproject/skupper/api/types"
 	"github.com/skupperproject/skupper/pkg/kube"
 	"gotest.tools/assert"
-	v1 "k8s.io/api/core/v1"
-	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
-	"k8s.io/client-go/kubernetes/fake"
 )
 
 var lightRed string = "\033[1;31m"
@@ -82,7 +79,7 @@ func TestSelfConnect(t *testing.T) {
 	defer os.RemoveAll(testPath)
 
 	// Create the connection token for Public ---------------------------------
-	connectionName := "link1"
+	connectionName := "conn1"
 	secretFileName := testPath + connectionName + ".yaml"
 	err = publicClient.ConnectorTokenCreateFile(ctx, connectionName, secretFileName)
 	assert.Assert(t, err, "Unable to create token")
@@ -129,7 +126,7 @@ func TestMultipleConnect(t *testing.T) {
 
 	// Use the token to make a connector.
 	_, err = userClient.ConnectorCreateFromFile(ctx, secretFileName, types.ConnectorCreateOptions{
-		Name:             "link1",
+		Name:             "conn1",
 		SkupperNamespace: tokenCreatorNamespace,
 		Cost:             1,
 	})
@@ -189,138 +186,3 @@ func configureSiteAndCreateRouter(t *testing.T, ctx context.Context, cli *VanCli
 	err = cli.RouterCreate(ctx, *siteConfig)
 	assert.Assert(t, err, "Unable to create %s VAN router", name)
 }
-
-func TestVerifySiteCompatibility(t *testing.T) {
-
-	testTable := []struct {
-		siteVersion       string
-		minimumCompatible string
-		clientSiteVersion string
-		accept            bool
-	}{
-		{
-			siteVersion:       "0.8.0",
-			minimumCompatible: "0.8.0",
-			clientSiteVersion: "",
-			accept:            false,
-		},
-		{
-			siteVersion:       "0.8.0",
-			minimumCompatible: "0.8.0",
-			clientSiteVersion: "0.7.0",
-			accept:            false,
-		},
-		{
-			siteVersion:       "nodeport-338-g6558216-modified",
-			minimumCompatible: "0.8.0",
-			clientSiteVersion: "0.7.0",
-			accept:            true,
-		},
-		{
-			siteVersion:       "nodeport-338-g6558216",
-			minimumCompatible: "0.8.0",
-			clientSiteVersion: "0.8.0",
-			accept:            true,
-		},
-		{
-			siteVersion:       "0.8.0",
-			minimumCompatible: "0.8.0",
-			clientSiteVersion: "nodeport-338-g6558216",
-			accept:            true,
-		},
-		{
-			siteVersion:       "nodeport-338-g6558216",
-			minimumCompatible: "0.8.0",
-			clientSiteVersion: "nodeport-338-g6558216",
-			accept:            true,
-		},
-		{
-			siteVersion:       "0.8.0",
-			minimumCompatible: "0.8.0",
-			clientSiteVersion: "0.8.0",
-			accept:            true,
-		},
-		{
-			siteVersion:       "0.8.0",
-			minimumCompatible: "0.8.0",
-			clientSiteVersion: "0.8.1",
-			accept:            true,
-		},
-		{
-			siteVersion:       "0.8.0",
-			minimumCompatible: "0.8.0",
-			clientSiteVersion: "0.9.0",
-			accept:            true,
-		},
-		{
-			siteVersion:       "0.9.0",
-			minimumCompatible: "0.8.0",
-			clientSiteVersion: "0.8.0",
-			accept:            true,
-		},
-		{
-			siteVersion:       "0.10.0",
-			minimumCompatible: "0.8.0",
-			clientSiteVersion: "0.8.0",
-			accept:            true,
-		},
-		{
-			siteVersion:       "0.10.0",
-			minimumCompatible: "0.9.1",
-			clientSiteVersion: "0.9.0",
-			accept:            false,
-		},
-		{
-			siteVersion:       "0.10.0",
-			minimumCompatible: "0.9.1",
-			clientSiteVersion: "0.9.1",
-			accept:            true,
-		},
-	}
-
-	var cli *VanClient
-	var err error
-
-	cli, err = newMockClient("fakens", "", "")
-	assert.Assert(t, err)
-
-	// Generates a fake client that simulates a skupper-internal using a specific version
-	initKubeClient := func(siteVersion string) {
-		cli.KubeClient = fake.NewSimpleClientset(&v1.ConfigMap{
-			ObjectMeta: metav1.ObjectMeta{
-				Namespace: "fakens",
-				Name:      types.TransportConfigMapName,
-			},
-			Data: map[string]string{
-				"qdrouterd.json": `
-    [
-        [
-            "router",
-            {
-                "id": "skupper-fakens",
-                "mode": "interior",
-                "helloMaxAgeSeconds": "3",
-                "metadata": "{\"id\":\"my-fake-site-id\",\"version\":\"` + siteVersion + `\"}"
-            }
-        ]
-    ]
-`,
-			},
-		})
-	}
-
-	originalMinimumCompatible := minimumCompatibleVersion
-	for _, test := range testTable {
-		name := fmt.Sprintf("site-%s-minimum-%s-provided-%s", test.siteVersion, minimumCompatibleVersion, test.clientSiteVersion)
-		t.Run(name, func(t *testing.T) {
-			minimumCompatibleVersion = test.minimumCompatible
-			initKubeClient(test.siteVersion)
-			compatErr := cli.VerifySiteCompatibility(test.clientSiteVersion)
-			assert.Assert(t, test.accept == (compatErr == nil))
-			if !test.accept {
-				assert.Assert(t, compatErr.Error() == fmt.Sprintf("minimum version required %s", test.minimumCompatible))
-			}
-		})
-	}
-	minimumCompatibleVersion = originalMinimumCompatible
-}
