@@ -4,10 +4,8 @@ import (
 	"context"
 
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
-
-	"github.com/skupperproject/skupper/api/types"
 )
 
 func (cli *VanClient) SiteConfigRemove(ctx context.Context) error {
-	return cli.KubeClient.CoreV1().ConfigMaps(cli.Namespace).Delete(types.SiteConfigMapName, &metav1.DeleteOptions{})
+	return cli.KubeClient.CoreV1().ConfigMaps(cli.Namespace).Delete("skupper-site", &metav1.DeleteOptions{})
 }
