@@ -3,7 +3,6 @@ package main
 import (
 	"crypto/tls"
 	"crypto/x509"
-	"flag"
 	"fmt"
 	"io/ioutil"
 	"log"
@@ -71,18 +70,6 @@ func getTlsConfig(verify bool, cert, key, ca string) (*tls.Config, error) {
 }
 
 func main() {
-	// if -version used, report and exit
-	isVersion := flag.Bool("version", false, "Report the version of the Skupper Service Controller")
-	flag.Parse()
-	if *isVersion {
-		fmt.Println(client.Version)
-		os.Exit(0)
-	}
-
-	// Startup message
-	log.Printf("Skupper service controller")
-	log.Printf("Version: %s", client.Version)
-
 	origin := os.Getenv("SKUPPER_SITE_ID")
 	namespace := os.Getenv("SKUPPER_NAMESPACE")
 	disableServiceSync := os.Getenv("SKUPPER_DISABLE_SERVICE_SYNC")
@@ -111,7 +98,7 @@ func main() {
 	log.Println("Waiting for Skupper router component to start")
 	_, err = kube.WaitDeploymentReady(types.TransportDeploymentName, namespace, cli.KubeClient, time.Second*180, time.Second*5)
 	if err != nil {
-		log.Fatal("Error waiting for transport deployment to be ready: ", err.Error())
+		log.Fatal("Error waiting for transport deployment to be ready", err.Error())
 	}
 
 	// start the controller workers
