@@ -6,7 +6,6 @@ import (
 	"reflect"
 	"strings"
 	"testing"
-	"time"
 
 	"github.com/google/go-cmp/cmp"
 	"github.com/skupperproject/skupper/api/types"
@@ -23,18 +22,18 @@ type serviceInterfaceUnbindCallArgs struct {
 }
 
 type serviceInterfaceBindCallArgs struct {
-	service     *types.ServiceInterface
-	targetType  string
-	targetName  string
-	protocol    string
-	targetPorts map[int]int
+	service    *types.ServiceInterface
+	targetType string
+	targetName string
+	protocol   string
+	targetPort int
 }
 
 type getHeadlessServiceConfigurationCallArgs struct {
 	targetName string
 	protocol   string
 	address    string
-	ports      []int
+	port       int
 }
 
 type siteConfigInspectCallArgs struct {
@@ -111,7 +110,7 @@ func (v *vanClientMock) RouterUpdateVersionInNamespace(ctx context.Context, hup
 func (v *vanClientMock) ConnectorCreateFromFile(ctx context.Context, secretFile string, options types.ConnectorCreateOptions) (*corev1.Secret, error) {
 	return nil, nil
 }
-func (v *vanClientMock) ConnectorCreateSecretFromData(ctx context.Context, secretData []byte, options types.ConnectorCreateOptions) (*corev1.Secret, error) {
+func (v *vanClientMock) ConnectorCreateSecretFromFile(ctx context.Context, secretFile string, options types.ConnectorCreateOptions) (*corev1.Secret, error) {
 	return nil, nil
 }
 
@@ -119,10 +118,10 @@ func (v *vanClientMock) ConnectorCreate(ctx context.Context, secret *corev1.Secr
 	return nil
 }
 
-func (v *vanClientMock) ConnectorInspect(ctx context.Context, name string) (*types.LinkStatus, error) {
+func (v *vanClientMock) ConnectorInspect(ctx context.Context, name string) (*types.ConnectorInspectResponse, error) {
 	return nil, nil
 }
-func (v *vanClientMock) ConnectorList(ctx context.Context) ([]types.LinkStatus, error) {
+func (v *vanClientMock) ConnectorList(ctx context.Context) ([]*types.Connector, error) {
 	return nil, nil
 }
 func (v *vanClientMock) ConnectorRemove(ctx context.Context, options types.ConnectorRemoveOptions) error {
@@ -134,12 +133,6 @@ func (v *vanClientMock) ConnectorTokenCreate(ctx context.Context, subject string
 func (v *vanClientMock) ConnectorTokenCreateFile(ctx context.Context, subject string, secretFile string) error {
 	return nil
 }
-func (v *vanClientMock) TokenClaimCreate(ctx context.Context, name string, password []byte, expiry time.Duration, uses int) (*corev1.Secret, bool, error) {
-	return nil, true, nil
-}
-func (v *vanClientMock) TokenClaimCreateFile(ctx context.Context, subject string, password []byte, expiry time.Duration, uses int, secretFile string) error {
-	return nil
-}
 func (v *vanClientMock) ServiceInterfaceCreate(ctx context.Context, service *types.ServiceInterface) error {
 	return nil
 }
@@ -156,58 +149,6 @@ func (v *vanClientMock) ServiceInterfaceUnbind(ctx context.Context, targetType s
 	return v.injectedReturns.serviceInterfaceUnbind
 }
 
-func (v *vanClientMock) GatewayBind(ctx context.Context, gatewayName string, endpoint types.GatewayEndpoint) error {
-	return nil
-}
-
-func (v *vanClientMock) GatewayUnbind(ctx context.Context, gatewayName string, endpoint types.GatewayEndpoint) error {
-	return nil
-}
-
-func (v *vanClientMock) GatewayExpose(ctx context.Context, gatewayName string, gatewayType string, endpoint types.GatewayEndpoint) (string, error) {
-	return "", nil
-}
-
-func (v *vanClientMock) GatewayUnexpose(ctx context.Context, gatewayName string, endpoint types.GatewayEndpoint, deleteLast bool) error {
-	return nil
-}
-
-func (v *vanClientMock) GatewayForward(ctx context.Context, gatewayName string, endpoint types.GatewayEndpoint, loopback bool) error {
-	return nil
-}
-
-func (v *vanClientMock) GatewayUnforward(ctx context.Context, gatewayName string, endpoint types.GatewayEndpoint) error {
-	return nil
-}
-
-func (v *vanClientMock) GatewayInit(ctx context.Context, gatewayName string, gatewayType string, configFile string) (string, error) {
-	return "", nil
-}
-
-func (v *vanClientMock) GatewayDownload(ctx context.Context, gatewayName string, downloadPath string) (string, error) {
-	return "", nil
-}
-
-func (v *vanClientMock) GatewayExportConfig(ctx context.Context, targetGatewayName string, exportGatewayName string, exportPath string) (string, error) {
-	return "", nil
-}
-
-func (cli *vanClientMock) GatewayGenerateBundle(ctx context.Context, configFile string, bundlePath string) (string, error) {
-	return "", nil
-}
-
-func (v *vanClientMock) GatewayInspect(ctx context.Context, gatewayName string) (*types.GatewayInspectResponse, error) {
-	return &types.GatewayInspectResponse{}, nil
-}
-
-func (v *vanClientMock) GatewayList(ctx context.Context) ([]*types.GatewayInspectResponse, error) {
-	return nil, nil
-}
-
-func (v *vanClientMock) GatewayRemove(ctx context.Context, gatewayName string) error {
-	return nil
-}
-
 func (v *vanClientMock) SiteConfigCreate(ctx context.Context, spec types.SiteConfigSpec) (*types.SiteConfig, error) {
 	v.siteConfigCreateCalledWith = append(v.siteConfigCreateCalledWith, spec)
 	return v.injectedReturns.siteConfigCreate.siteConfig, v.injectedReturns.siteConfigCreate.err
@@ -226,17 +167,17 @@ func (v *vanClientMock) SiteConfigRemove(ctx context.Context) error {
 	return nil
 }
 
-func (v *vanClientMock) SkupperDump(ctx context.Context, tarName string, version string, kubeConfigPath string, kubeConfigContext string) (string, error) {
-	return "", nil
+func (v *vanClientMock) SkupperDump(ctx context.Context, tarName string, version string, kubeConfigPath string, kubeConfigContext string) error {
+	return nil
 }
 
-func (v *vanClientMock) ServiceInterfaceBind(ctx context.Context, service *types.ServiceInterface, targetType string, targetName string, protocol string, targetPorts map[int]int) error {
+func (v *vanClientMock) ServiceInterfaceBind(ctx context.Context, service *types.ServiceInterface, targetType string, targetName string, protocol string, targetPort int) error {
 	var calledWith = serviceInterfaceBindCallArgs{
-		service:     service,
-		targetType:  targetType,
-		targetName:  targetName,
-		protocol:    protocol,
-		targetPorts: targetPorts,
+		service:    service,
+		targetType: targetType,
+		targetName: targetName,
+		protocol:   protocol,
+		targetPort: targetPort,
 	}
 	v.serviceInterfaceBindCalledWith = append(v.serviceInterfaceBindCalledWith, calledWith)
 
@@ -249,7 +190,7 @@ func (v *vanClientMock) ServiceInterfaceInspect(ctx context.Context, address str
 }
 
 func (v *vanClientMock) ServiceInterfaceList(ctx context.Context) ([]*types.ServiceInterface, error) {
-	// return []*ServiceInterface{}, nil
+	//return []*ServiceInterface{}, nil
 	return nil, nil
 }
 
@@ -262,12 +203,12 @@ func (v *vanClientMock) ServiceInterfaceUpdate(ctx context.Context, service *typ
 	return v.injectedReturns.serviceInterfaceUpdate
 }
 
-func (v *vanClientMock) GetHeadlessServiceConfiguration(targetName string, protocol string, address string, ports []int) (*types.ServiceInterface, error) {
+func (v *vanClientMock) GetHeadlessServiceConfiguration(targetName string, protocol string, address string, port int) (*types.ServiceInterface, error) {
 	var calledWith = getHeadlessServiceConfigurationCallArgs{
 		targetName: targetName,
 		protocol:   protocol,
 		address:    address,
-		ports:      ports,
+		port:       port,
 	}
 	v.getHeadlessServiceConfigurationCalledWith = append(v.getHeadlessServiceConfigurationCalledWith, calledWith)
 	return v.injectedReturns.getHeadlessServiceConfiguration.serviceInterface, v.injectedReturns.getHeadlessServiceConfiguration.err
@@ -281,10 +222,6 @@ func (cli *vanClientMock) GetVersion(component string, name string) string {
 	return "not-found"
 }
 
-func (v *vanClientMock) RevokeAccess(ctx context.Context) error {
-	return nil
-}
-
 func TestCmdUnexposeRun(t *testing.T) {
 	cmd := NewCmdUnexpose(nil)
 	test := func(targetType, targetName, address string) {
@@ -295,7 +232,7 @@ func TestCmdUnexposeRun(t *testing.T) {
 
 		args := []string{targetType}
 
-		// supporting "targetType TargetName" and "targetType/targetName" notations
+		//supporting "targetType TargetName" and "targetType/targetName" notations
 		if targetName != "" {
 			args = append(args, targetName)
 		} else {
@@ -403,11 +340,11 @@ func TestExpose_NotBinding(t *testing.T) {
 	var err error
 	ctx := context.Background()
 	options := ExposeOptions{
-		Protocol:    "",
-		Address:     "",
-		Ports:       []int{},
-		TargetPorts: []string{},
-		Headless:    false,
+		Protocol:   "",
+		Address:    "",
+		Port:       0,
+		TargetPort: 0,
+		Headless:   false,
 	}
 
 	t.Run("ServiceInterfaceInspect returns error",
@@ -439,7 +376,7 @@ func TestExpose_NotBinding(t *testing.T) {
 			cli.injectedReturns.getHeadlessServiceConfiguration.serviceInterface = aService
 
 			options.Protocol = "theprotocol"
-			options.Ports = []int{123}
+			options.Port = 123
 
 			_, err = expose(cli, ctx, "statefulset", "name", options)
 			assert.Assert(t, err)
@@ -451,7 +388,7 @@ func TestExpose_NotBinding(t *testing.T) {
 				targetName: "name",
 				protocol:   options.Protocol,
 				address:    "ServiceName",
-				ports:      options.Ports,
+				port:       options.Port,
 			}
 
 			assert.Assert(t, cmp.Equal(cli.getHeadlessServiceConfigurationCalledWith[0], expectedGetHead, cmp.AllowUnexported(getHeadlessServiceConfigurationCallArgs{})))
@@ -495,10 +432,10 @@ func TestExpose_Binding(t *testing.T) {
 		assert.Assert(t, a.targetType == b.targetType)
 		assert.Assert(t, a.targetName == b.targetName)
 		assert.Assert(t, a.protocol == b.protocol)
-		assert.Assert(t, reflect.DeepEqual(a.targetPorts, b.targetPorts))
+		assert.Assert(t, a.targetPort == b.targetPort)
 		assert.Assert(t, a.service.Address == b.service.Address)
 		assert.Assert(t, a.service.Protocol == b.service.Protocol)
-		assert.Assert(t, reflect.DeepEqual(a.service.Ports, b.service.Ports))
+		assert.Assert(t, a.service.Port == b.service.Port)
 	}
 	options := ExposeOptions{}
 
@@ -506,27 +443,25 @@ func TestExpose_Binding(t *testing.T) {
 	options.Address = "TheService"
 	options.Headless = false
 	options.Protocol = test_protocol
-	options.Ports = []int{123}
-	options.TargetPorts = []string{"123:234"}
+	options.Port = 123
+	options.TargetPort = 234
 
 	expectedBindCall := serviceInterfaceBindCallArgs{
 		service: &types.ServiceInterface{
 			Address:  "TheService",
 			Protocol: test_protocol,
-			Ports:    []int{123},
+			Port:     123,
 		},
-		targetType:  "any",
-		targetName:  "name",
-		protocol:    test_protocol,
-		targetPorts: map[int]int{123: 234},
+		targetType: "any",
+		targetName: "name",
+		protocol:   test_protocol,
+		targetPort: 234,
 	}
 
 	t.Run("service not existent and options.expose.headless == false",
 		func(t *testing.T) {
 			cli := &vanClientMock{}
 
-			fmt.Println("TARGET PORTS =", targetPorts)
-			fmt.Println("OPTIONS =", options)
 			exposedAs, err := expose(cli, ctx, "any", "name", options)
 			assert.Assert(t, err)
 			assert.Equal(t, exposedAs, "TheService")
@@ -540,7 +475,7 @@ func TestExpose_Binding(t *testing.T) {
 			cli := &vanClientMock{}
 			aService := &types.ServiceInterface{
 				Address:  "TheOtherService",
-				Ports:    options.Ports,
+				Port:     options.Port,
 				Protocol: options.Protocol,
 			}
 			expectedBindCall := expectedBindCall
@@ -575,7 +510,7 @@ func TestExpose_Binding(t *testing.T) {
 
 func TestCmdExposeRun(t *testing.T) {
 	cmd := NewCmdExpose(nil)
-	cli = &vanClientMock{} // the global cli is used by the "RunE" func
+	cli = &vanClientMock{} //the global cli is used by the "RunE" func
 	cli := cli.(*vanClientMock)
 
 	args := []string{"service", "name"}
@@ -584,7 +519,7 @@ func TestCmdExposeRun(t *testing.T) {
 	err := cmd.RunE(&cobra.Command{}, args)
 	assert.Error(t, err, "--address option is required for target type 'service'")
 
-	// hack: forcing a expose function call error
+	//hack: forcing a expose function call error
 	args = []string{"pods", "name"}
 	cli.injectedReturns.serviceInterfaceInspect.err = fmt.Errorf("some error")
 	err = cmd.RunE(&cobra.Command{}, args)
@@ -630,7 +565,6 @@ func TestCmdBind(t *testing.T) {
 
 	injectedService := &types.ServiceInterface{
 		Protocol: "tcp",
-		Ports:    []int{567},
 		Headless: &types.Headless{
 			Name: "NotNil",
 		},
@@ -640,8 +574,7 @@ func TestCmdBind(t *testing.T) {
 		func(t *testing.T) {
 			resetCli()
 			protocol = "tcp"
-			targetPorts = []string{"567:567"}
-			expectedTargetPorts := map[int]int{567: 567}
+			targetPort = 567
 			args = []string{"TheService", "type", "name"}
 			lcli.injectedReturns.serviceInterfaceInspect.serviceInterface = injectedService
 			err := cmd.RunE(&cobra.Command{}, args)
@@ -651,7 +584,7 @@ func TestCmdBind(t *testing.T) {
 			assert.Assert(t, c.protocol == "tcp")
 			assert.Assert(t, c.targetType == "type")
 			assert.Assert(t, c.targetName == "name")
-			assert.Assert(t, reflect.DeepEqual(c.targetPorts, expectedTargetPorts))
+			assert.Assert(t, c.targetPort == 567)
 			assert.Assert(t, c.service == injectedService)
 
 		})
@@ -660,7 +593,7 @@ func TestCmdBind(t *testing.T) {
 		func(t *testing.T) {
 			resetCli()
 			protocol = "tcp"
-			targetPorts = []string{"567"}
+			targetPort = 567
 			args = []string{"TheService", "type", "name"}
 			lcli.injectedReturns.serviceInterfaceInspect.serviceInterface = injectedService
 			lcli.injectedReturns.serviceInterfaceBind = fmt.Errorf("some error")
