@@ -3,9 +3,8 @@ package kube
 import (
 	"context"
 	"fmt"
-	"time"
-
 	"github.com/skupperproject/skupper/pkg/utils"
+	"time"
 
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
@@ -27,7 +26,7 @@ func GetDeploymentLabel(name string, key string, namespace string, cli kubernete
 	return ""
 }
 
-func GetPods(selector string, namespace string, cli kubernetes.Interface) ([]corev1.Pod, error) {
+func GetDeploymentPods(name string, selector string, namespace string, cli kubernetes.Interface) ([]corev1.Pod, error) {
 	options := metav1.ListOptions{LabelSelector: selector}
 	podList, err := cli.CoreV1().Pods(namespace).List(options)
 	if err != nil {
@@ -113,15 +112,6 @@ func NewProxyStatefulSet(image types.ImageDetails, serviceInterface types.Servic
 	ownerRef := GetDeploymentOwnerReference(transportDep)
 
 	replicas := int32(serviceInterface.Headless.Size)
-	labels := map[string]string{
-		"internal.skupper.io/type": "proxy",
-	}
-	if len(serviceInterface.Labels) > 0 {
-		for k, v := range serviceInterface.Labels {
-			labels[k] = v
-		}
-	}
-
 	proxyStatefulSet := &appsv1.StatefulSet{
 		TypeMeta: metav1.TypeMeta{
 			APIVersion: "apps/v1",
@@ -134,7 +124,9 @@ func NewProxyStatefulSet(image types.ImageDetails, serviceInterface types.Servic
 			Annotations: map[string]string{
 				types.ServiceQualifier: serviceInterface.Address,
 			},
-			Labels: labels,
+			Labels: map[string]string{
+				"internal.skupper.io/type": "proxy",
+			},
 		},
 		Spec: appsv1.StatefulSetSpec{
 			ServiceName: serviceInterface.Address,
@@ -198,46 +190,6 @@ func NewProxyStatefulSet(image types.ImageDetails, serviceInterface types.Servic
 		},
 	}
 
-	podspec := &proxyStatefulSet.Spec.Template.Spec
-	if len(serviceInterface.Headless.NodeSelector) > 0 {
-		podspec.NodeSelector = serviceInterface.Headless.NodeSelector
-	}
-
-	if len(serviceInterface.Headless.Affinity) > 0 || len(serviceInterface.Headless.AntiAffinity) > 0 {
-		podspec.Affinity = &corev1.Affinity{}
-		if len(serviceInterface.Headless.Affinity) > 0 {
-			podspec.Affinity.PodAffinity = &corev1.PodAffinity{
-				PreferredDuringSchedulingIgnoredDuringExecution: []corev1.WeightedPodAffinityTerm{
-					{
-						Weight: 100,
-						PodAffinityTerm: corev1.PodAffinityTerm{
-							LabelSelector: &metav1.LabelSelector{
-								MatchLabels: serviceInterface.Headless.Affinity,
-							},
-							TopologyKey: "kubernetes.io/hostname",
-						},
-					},
-				},
-			}
-		}
-		if len(serviceInterface.Headless.AntiAffinity) > 0 {
-			podspec.Affinity.PodAntiAffinity = &corev1.PodAntiAffinity{
-				PreferredDuringSchedulingIgnoredDuringExecution: []corev1.WeightedPodAffinityTerm{
-					{
-						Weight: 100,
-						PodAffinityTerm: corev1.PodAffinityTerm{
-							LabelSelector: &metav1.LabelSelector{
-								MatchLabels: serviceInterface.Headless.AntiAffinity,
-							},
-							TopologyKey: "kubernetes.io/hostname",
-						},
-					},
-				},
-			}
-		}
-	}
-	setResourceRequests(&podspec.Containers[0], serviceInterface.Headless)
-
 	created, err := statefulSets.Create(proxyStatefulSet)
 
 	if err != nil {
@@ -266,7 +218,7 @@ func NewControllerDeployment(van *types.RouterSpec, ownerRef *metav1.OwnerRefere
 			Spec: appsv1.DeploymentSpec{
 				Replicas: &van.Controller.Replicas,
 				Selector: &metav1.LabelSelector{
-					MatchLabels: van.Controller.LabelSelector,
+					MatchLabels: van.Controller.Labels,
 				},
 				Template: corev1.PodTemplateSpec{
 					ObjectMeta: metav1.ObjectMeta{
@@ -284,7 +236,6 @@ func NewControllerDeployment(van *types.RouterSpec, ownerRef *metav1.OwnerRefere
 			dep.ObjectMeta.OwnerReferences = []metav1.OwnerReference{*ownerRef}
 		}
 
-		setAffinity(&van.Controller, &dep.Spec.Template.Spec)
 		for _, sc := range van.Controller.Sidecars {
 			dep.Spec.Template.Spec.Containers = append(dep.Spec.Template.Spec.Containers, *sc)
 		}
@@ -307,46 +258,6 @@ func NewControllerDeployment(van *types.RouterSpec, ownerRef *metav1.OwnerRefere
 	}
 }
 
-func setAffinity(spec *types.DeploymentSpec, podspec *corev1.PodSpec) {
-	if len(spec.NodeSelector) > 0 {
-		podspec.NodeSelector = spec.NodeSelector
-	}
-
-	if len(spec.Affinity) > 0 || len(spec.AntiAffinity) > 0 {
-		podspec.Affinity = &corev1.Affinity{}
-		if len(spec.Affinity) > 0 {
-			podspec.Affinity.PodAffinity = &corev1.PodAffinity{
-				PreferredDuringSchedulingIgnoredDuringExecution: []corev1.WeightedPodAffinityTerm{
-					{
-						Weight: 100,
-						PodAffinityTerm: corev1.PodAffinityTerm{
-							LabelSelector: &metav1.LabelSelector{
-								MatchLabels: spec.Affinity,
-							},
-							TopologyKey: "kubernetes.io/hostname",
-						},
-					},
-				},
-			}
-		}
-		if len(spec.AntiAffinity) > 0 {
-			podspec.Affinity.PodAntiAffinity = &corev1.PodAntiAffinity{
-				PreferredDuringSchedulingIgnoredDuringExecution: []corev1.WeightedPodAffinityTerm{
-					{
-						Weight: 100,
-						PodAffinityTerm: corev1.PodAffinityTerm{
-							LabelSelector: &metav1.LabelSelector{
-								MatchLabels: spec.AntiAffinity,
-							},
-							TopologyKey: "kubernetes.io/hostname",
-						},
-					},
-				},
-			}
-		}
-	}
-}
-
 func NewTransportDeployment(van *types.RouterSpec, ownerRef *metav1.OwnerReference, cli kubernetes.Interface) (*appsv1.Deployment, error) {
 	deployments := cli.AppsV1().Deployments(van.Namespace)
 	existing, err := deployments.Get(types.TransportDeploymentName, metav1.GetOptions{})
@@ -365,7 +276,7 @@ func NewTransportDeployment(van *types.RouterSpec, ownerRef *metav1.OwnerReferen
 			Spec: appsv1.DeploymentSpec{
 				Replicas: &van.Transport.Replicas,
 				Selector: &metav1.LabelSelector{
-					MatchLabels: van.Transport.LabelSelector,
+					MatchLabels: van.Transport.Labels,
 				},
 				Template: corev1.PodTemplateSpec{
 					ObjectMeta: metav1.ObjectMeta{
@@ -382,7 +293,6 @@ func NewTransportDeployment(van *types.RouterSpec, ownerRef *metav1.OwnerReferen
 			},
 		}
 
-		setAffinity(&van.Transport, &dep.Spec.Template.Spec)
 		for _, sc := range van.Transport.Sidecars {
 			dep.Spec.Template.Spec.Containers = append(dep.Spec.Template.Spec.Containers, *sc)
 		}
@@ -410,27 +320,27 @@ func NewTransportDeployment(van *types.RouterSpec, ownerRef *metav1.OwnerReferen
 	}
 }
 
-func GetContainerPort(deployment *appsv1.Deployment) map[int]int {
+func GetContainerPort(deployment *appsv1.Deployment) int32 {
 	if len(deployment.Spec.Template.Spec.Containers) > 0 && len(deployment.Spec.Template.Spec.Containers[0].Ports) > 0 {
-		return GetAllContainerPorts(deployment.Spec.Template.Spec.Containers[0])
+		return deployment.Spec.Template.Spec.Containers[0].Ports[0].ContainerPort
 	} else {
-		return map[int]int{}
+		return 0
 	}
 }
 
-func GetContainerPortForStatefulSet(statefulSet *appsv1.StatefulSet) map[int]int {
+func GetContainerPortForStatefulSet(statefulSet *appsv1.StatefulSet) int32 {
 	if len(statefulSet.Spec.Template.Spec.Containers) > 0 && len(statefulSet.Spec.Template.Spec.Containers[0].Ports) > 0 {
-		return GetAllContainerPorts(statefulSet.Spec.Template.Spec.Containers[0])
+		return statefulSet.Spec.Template.Spec.Containers[0].Ports[0].ContainerPort
 	} else {
-		return map[int]int{}
+		return 0
 	}
 }
 
-func GetContainerPortForDaemonSet(daemonSet *appsv1.DaemonSet) map[int]int {
+func GetContainerPortForDaemonSet(daemonSet *appsv1.DaemonSet) int32 {
 	if len(daemonSet.Spec.Template.Spec.Containers) > 0 && len(daemonSet.Spec.Template.Spec.Containers[0].Ports) > 0 {
-		return GetAllContainerPorts(daemonSet.Spec.Template.Spec.Containers[0])
+		return daemonSet.Spec.Template.Spec.Containers[0].Ports[0].ContainerPort
 	} else {
-		return map[int]int{}
+		return 0
 	}
 }
 
@@ -481,11 +391,9 @@ func WaitDeploymentReady(name string, namespace string, cli kubernetes.Interface
 	defer cancel()
 	err = utils.RetryWithContext(ctx, interval, func() (bool, error) {
 		dep, err = cli.AppsV1().Deployments(namespace).Get(name, metav1.GetOptions{})
-		if errors.IsNotFound(err) {
+		if err != nil {
 			// dep does not exist yet
 			return false, nil
-		} else if err != nil {
-			return false, err
 		}
 		return dep.Status.ReadyReplicas > 0, nil
 	})
