@@ -1,6 +1,8 @@
 package kube
 
 import (
+	"fmt"
+
 	rbacv1 "k8s.io/api/rbac/v1"
 	"k8s.io/client-go/kubernetes"
 )
@@ -9,7 +11,7 @@ func CreateRoleBinding(namespace string, rb *rbacv1.RoleBinding, kubeclient kube
 	roleBindings := kubeclient.RbacV1().RoleBindings(namespace)
 	created, err := roleBindings.Create(rb)
 	if err != nil {
-		return nil, err
+		return nil, fmt.Errorf("Failed to create role binding: %w", err)
 	} else {
 		return created, nil
 	}
