@@ -1,6 +1,8 @@
 package kube
 
 import (
+	"fmt"
+
 	rbacv1 "k8s.io/api/rbac/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/client-go/kubernetes"
@@ -10,25 +12,12 @@ func CreateRole(namespace string, role *rbacv1.Role, kubeclient kubernetes.Inter
 	roles := kubeclient.RbacV1().Roles(namespace)
 	created, err := roles.Create(role)
 	if err != nil {
-		return nil, err
+		return nil, fmt.Errorf("Failed to create role: %w", err)
 	} else {
 		return created, nil
 	}
 }
 
-func UpdateRole(namespace string, name string, rules []rbacv1.PolicyRule, kubeclient kubernetes.Interface) error {
-	role, err := kubeclient.RbacV1().Roles(namespace).Get(name, metav1.GetOptions{})
-	if err != nil {
-		return err
-	}
-	role.Rules = rules
-	_, err = kubeclient.RbacV1().Roles(namespace).Update(role)
-	if err != nil {
-		return err
-	}
-	return nil
-}
-
 func CopyRole(src string, dest string, namespace string, kubeclient kubernetes.Interface) error {
 	original, err := kubeclient.RbacV1().Roles(namespace).Get(src, metav1.GetOptions{})
 	if err != nil {
