@@ -1,6 +1,8 @@
 package kube
 
 import (
+	"fmt"
+
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/client-go/kubernetes"
@@ -10,7 +12,7 @@ func CreateServiceAccount(namespace string, sa *corev1.ServiceAccount, cli kuber
 	serviceAccounts := cli.CoreV1().ServiceAccounts(namespace)
 	created, err := serviceAccounts.Create(sa)
 	if err != nil {
-		return nil, err
+		return nil, fmt.Errorf("Failed to create service account: %w", err)
 	} else {
 		return created, nil
 	}
