@@ -2,6 +2,7 @@ package qdr
 
 import (
 	"flag"
+	"strings"
 	"testing"
 
 	"crypto/tls"
@@ -105,7 +106,7 @@ func TestQDR(t *testing.T) {
 
 	// Get ------------------------------------
 	agent, err := agentPool.Get()
-	assert.Assert(t, agent == nil && err != nil, "AgentPool.Get() should have failed but didn't")
+	assert.Assert(t, agent == nil && strings.Contains(err.Error(), "refused"), "AgentPool.Get() should have failed but didn't.")
 
 	// isOk ----------------------------------------
 	code := 199
