@@ -1,4 +1,4 @@
-// +build integration smoke
+// +build integration
 
 package basic
 
@@ -8,7 +8,6 @@ import (
 	"testing"
 
 	"github.com/skupperproject/skupper/test/utils/base"
-	"gotest.tools/assert"
 )
 
 func TestMain(m *testing.M) {
@@ -23,13 +22,9 @@ func TestBasic(t *testing.T) {
 		PrivateClusters: 1,
 	}
 	testRunner := &BasicTestRunner{}
-	if err := testRunner.Validate(needs); err != nil {
-		t.Skipf("%s", err)
-	}
-	_, err := testRunner.Build(needs, nil)
-	assert.Assert(t, err)
+	testRunner.BuildOrSkip(t, needs, nil)
 	ctx, cancel := context.WithCancel(context.Background())
-	base.HandleInterruptSignal(func() {
+	base.HandleInterruptSignal(t, func(t *testing.T) {
 		testRunner.TearDown(ctx)
 		cancel()
 	})
