@@ -1,4 +1,4 @@
-// +build integration smoke
+// +build integration
 
 package tcp_echo
 
@@ -8,6 +8,8 @@ import (
 	"testing"
 
 	"github.com/skupperproject/skupper/test/utils/base"
+	"github.com/skupperproject/skupper/test/utils/k8s"
+
 	"gotest.tools/assert"
 	_ "k8s.io/client-go/plugin/pkg/client/auth"
 )
@@ -25,15 +27,16 @@ func TestTcpEcho(t *testing.T) {
 		PrivateClusters: 1,
 	}
 	testRunner := &TcpEchoClusterTestRunner{}
-	if err := testRunner.Validate(needs); err != nil {
-		t.Skipf("%s", err)
-	}
-	_, err := testRunner.Build(needs, nil)
-	assert.Assert(t, err)
+	testRunner.BuildOrSkip(t, needs, nil)
 	ctx, cancel := context.WithCancel(context.Background())
-	base.HandleInterruptSignal(func() {
+	base.HandleInterruptSignal(t, func(t *testing.T) {
 		base.TearDownSimplePublicAndPrivate(&testRunner.ClusterTestRunnerBase)
 		cancel()
 	})
 	testRunner.Run(ctx, t)
 }
+
+func TestTcpEchoJob(t *testing.T) {
+	k8s.SkipTestJobIfMustBeSkipped(t)
+	assert.Assert(t, SendReceive("tcp-go-echo:9090"))
+}
